@@ -24,6 +24,9 @@ CHANGELOG = ChangeLog(
     Version('0.3.1',
         'Added the member attribute extensions',
         ),
+    Version('0.3.2',
+        'Added contexts',
+        ),
 )
 
 __doc__ += '\n' + str(CHANGELOG)
